@@ -18,5 +18,8 @@ void init_crop(double ***land, double *paras, double **C_init);
 
 void change_crop_choice(double **C_init, double **C_change, double *paras);
 
+void grow_crops(double ***land, double *grow, double *paras);
+
 void land_change(double ***land, double *paras, int ts, double **C_init,
-                 double **C_change, double **P_init, double **P_change);
+                 double **C_change, double **P_init, double **P_change,
+                 double *grow);
